Package: Uniquorn
Title: Identification of cancer cell lines based on their weighted
        mutational/ variational fingerprint
Version: 2.33.0
Authors@R: person("Raik", "Otto", email = "raik.otto@hu-berlin.de", role = c("aut", "cre"))
Description: 'Uniquorn' enables users to identify cancer cell lines.
 Cancer cell line misidentification and cross-contamination reprents a significant challenge for cancer researchers. 
 The identification is vital and in the frame of this package based on the locations/ loci of somatic and germline mutations/ variations.
 The input format is vcf/ vcf.gz and the files have to contain a single cancer cell line sample 
 (i.e. a single member/genotype/gt column in the vcf file).
Imports: stringr, R.utils, WriteXLS, stats, doParallel, foreach,
        GenomicRanges, IRanges, VariantAnnotation, data.table
Depends: R (>= 3.5)
License: Artistic-2.0
Type: Package
Date: 2025-10-22
Author: Raik Otto
RoxygenNote: 7.2.3
NeedsCompilation: no
Suggests: testthat, knitr, rmarkdown, BiocGenerics
biocViews: ImmunoOncology, StatisticalMethod, WholeGenome, ExomeSeq
VignetteBuilder: knitr
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/Uniquorn
git_branch: devel
git_last_commit: f9ade8c
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
Packaged: 2026-05-18 23:45:39 UTC; biocbuild
Maintainer: Raik Otto <raik.otto@hu-berlin.de>
Built: R 4.6.0; ; 2026-05-19 05:13:14 UTC; unix
