# Generated by roxygen2: do not edit by hand

export(add_custom_vcf_to_database)
export(identify_vcf_file)
export(initiate_canonical_databases)
export(read_library_names)
export(remove_ccls_from_database)
export(remove_library_from_database)
export(show_contained_ccls)
export(show_contained_variants_for_ccl)
export(show_contained_variants_in_library)
export(show_which_ccls_contain_variant)
import(GenomicRanges)
import(IRanges)
import(R.utils)
import(WriteXLS)
import(foreach)
import(stringr)
importFrom(IRanges,IRanges)
importFrom(IRanges,findOverlaps)
importFrom(IRanges,subsetByOverlaps)
importFrom(VariantAnnotation,readVcf)
importFrom(data.table,fread)
importFrom(stats,aggregate)
importFrom(stats,integrate)
importFrom(stats,pbeta)
importFrom(stats,pbinom)
