% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/add_missing_cls.R
\name{add_missing_cls}
\alias{add_missing_cls}
\title{add_missing_cls}
\usage{
add_missing_cls(res_table, dif_cls)
}
\arguments{
\item{res_table}{Table that contains the identification results}

\item{dif_cls}{Missing CLs}
}
\value{
Results table with added missing cls
}
\description{
add_missing_cls
}
