% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Parse_COSMIC_CCLE_CCLs.R
\name{parse_ccle_genotype_data}
\alias{parse_ccle_genotype_data}
\title{parse_ccle_genotype_data}
\usage{
parse_ccle_genotype_data(ccle_file, ccle_sample_file, ref_gen = "GRCH38")
}
\arguments{
\item{ccle_file}{Path to CCLE file on hard disk}

\item{ccle_sample_file}{Path to CCLE sample file}

\item{ref_gen}{Reference genome version}
}
\value{
The R Table sim_list which contains the CCLE fingerprints
}
\description{
Parses ccle genotype data
}
\keyword{internal}
